==> scala-k8s-objects_sjs1_2.13-0.1.0-sources.jar: io/k8s/apiextensions-apiserver/pkg/apis/apiextensions/v1/CustomResourceDefinitionSpec.scala <==
package io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1


/** CustomResourceDefinitionSpec describes how a user wants their resource to appear */
final case class CustomResourceDefinitionSpec(
  versions : Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion],
  scope : String,
  names : io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames,
  group : String,
  conversion : Option[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion] = None,
  preserveUnknownFields : Option[Boolean] = None
) {

  /** Returns a new data with versions set to new value */
  def withVersions(value: Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion]) : CustomResourceDefinitionSpec = copy(versions = value)
  /** Appends new values to versions */
  def addVersions(newValues: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion*) : CustomResourceDefinitionSpec = copy(versions = versions ++ newValues)
  /** transforms versions to result of function */
  def mapVersions(f: Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion] => Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion]) : CustomResourceDefinitionSpec = copy(versions = f(versions))

  /** Returns a new data with scope set to new value */
  def withScope(value: String) : CustomResourceDefinitionSpec = copy(scope = value)
  /** transforms scope to result of function */
  def mapScope(f: String => String) : CustomResourceDefinitionSpec = copy(scope = f(scope))

  /** Returns a new data with names set to new value */
  def withNames(value: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames) : CustomResourceDefinitionSpec = copy(names = value)
  /** transforms names to result of function */
  def mapNames(f: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames => io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames) : CustomResourceDefinitionSpec = copy(names = f(names))

  /** Returns a new data with group set to new value */
  def withGroup(value: String) : CustomResourceDefinitionSpec = copy(group = value)
  /** transforms group to result of function */
  def mapGroup(f: String => String) : CustomResourceDefinitionSpec = copy(group = f(group))

  /** Returns a new data with conversion set to new value */
  def withConversion(value: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion) : CustomResourceDefinitionSpec = copy(conversion = Some(value))
  /** if conversion has a value, transforms to the result of function*/
  def mapConversion(f: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion => io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion) : CustomResourceDefinitionSpec = copy(conversion = conversion.map(f))

  /** Returns a new data with preserveUnknownFields set to new value */
  def withPreserveUnknownFields(value: Boolean) : CustomResourceDefinitionSpec = copy(preserveUnknownFields = Some(value))
  /** if preserveUnknownFields has a value, transforms to the result of function*/
  def mapPreserveUnknownFields(f: Boolean => Boolean) : CustomResourceDefinitionSpec = copy(preserveUnknownFields = preserveUnknownFields.map(f))
}

==> scala-k8s-objects_sjs1_3-0.0.1-sources.jar: io/k8s/apiextensions-apiserver/pkg/apis/apiextensions/v1/CustomResourceDefinitionSpec.scala <==
package io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1


/** CustomResourceDefinitionSpec describes how a user wants their resource to appear */
final case class CustomResourceDefinitionSpec(
  conversion : Option[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion] = None,
  versions : Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion],
  scope : String,
  names : io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames,
  preserveUnknownFields : Option[Boolean] = None,
  group : String
) {
  def withConversion(value: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceConversion) : CustomResourceDefinitionSpec = copy(conversion = Some(value))
  def withVersions(value: Seq[io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion]) : CustomResourceDefinitionSpec = copy(versions = value)
  def addVersions(newValues: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionVersion*) : CustomResourceDefinitionSpec = copy(versions = versions ++ newValues)

  def withScope(value: String) : CustomResourceDefinitionSpec = copy(scope = value)
  def withNames(value: io.k8s.apiextensions_apiserver.pkg.apis.apiextensions.v1.CustomResourceDefinitionNames) : CustomResourceDefinitionSpec = copy(names = value)
  def withPreserveUnknownFields(value: Boolean) : CustomResourceDefinitionSpec = copy(preserveUnknownFields = Some(value))
  def withGroup(value: String) : CustomResourceDefinitionSpec = copy(group = value)
}
